function IsNullOrEmpty(v)
{
	return v == null || typeof v == 'undefined';
}

function BindShowHideForOptionSet(fieldName, targetFieldName, displayName, showValue = '1')
{
	var field = $('#' + fieldName);
	
	if (IsNullOrEmpty(field))
	{
		return;
	}
	
	CreateFieldValidator(targetFieldName, displayName);
	ShowHideForOptionSet(fieldName, targetFieldName, showValue);
	
	field.change(function()
	{
		ShowHideForOptionSet(fieldName, targetFieldName, showValue);
	});
}

function ShowHideForOptionSet(fieldName, targetFieldName, showValue = '1')
{
	var optionSetField = $('#' + fieldName);
	var targetField = $('#' + targetFieldName);
	
	if (IsNullOrEmpty(optionSetField) || IsNullOrEmpty(targetField))
	{
		return;
	}
	
	var value = optionSetField.find('input:checked').val();
	
	if (value == showValue)
	{
		targetField.closest('td').show();
		SetFieldRequired(targetFieldName);
	}
	else
	{
		targetField.closest('td').hide();
		SetFieldNotRequired(targetFieldName);
	}
}

function SetFieldRequired(fieldName)
{
	var fieldLabel = $('#' + fieldName + '_label');
	
	if (!IsNullOrEmpty(fieldLabel))
	{
		fieldLabel.parent().addClass('required');
	}
	
	SetFieldValidatorEnabled(fieldName, true);
}

function SetFieldNotRequired(fieldName)
{
	var fieldLabel = $('#' + fieldName + '_label');
	
	if (!IsNullOrEmpty(fieldLabel))
	{
		fieldLabel.parent().removeClass('required');
	}
	
	SetFieldValidatorEnabled(fieldName, false);
}

function CreateFieldValidator(fieldName, displayName)
{
	if (!IsNullOrEmpty(Page_Validators))
	{
		console.log('Creating validator for ' + fieldName);
	
		var newValidator = document.createElement('span');
		newValidator.style.display = 'none';
		newValidator.id = 'DynamicRequiredFieldValidator' + fieldName;
		newValidator.controltovalidate = fieldName;
		newValidator.errormessage = "<a href='#" + fieldName + "' referencecontrolid='" + fieldName + "' onclick='javascript:scrollToAndFocus(\"" + fieldName + "_label\", \"" + fieldName + "\");return false;'>" + displayName + " is a required field.</a>";
		newValidator.validationGroup = '';
		newValidator.initialvalue = '';
		newValidator.enabled = false;
		newValidator.evaluationfunction = function ()
		{
			var value = $('#' + fieldName).val();
			if (value == null || value == "")
			{
				return false;
			}
			else
			{
				return true;
			}
		};

		Page_Validators.push(newValidator);
		
		/*console.log(Page_Validators.length);
		
		for (var i = 0; i < Page_Validators.length; i++)
		{
			var validator = Page_Validators[i];
			console.log(validator.id);
		}*/
	}
}

function SetFieldValidatorEnabled(fieldName, enabled)
{
	if (!IsNullOrEmpty(Page_Validators))
	{
		var validatorName = 'DynamicRequiredFieldValidator' + fieldName;
		
		for (var i = 0; i < Page_Validators.length; i++)
		{
			var validator = Page_Validators[i];
			
			if (validator.id == validatorName)
			{
				//console.log('Set validator for ' + fieldName + ' - enabled = ' + enabled);
				validator.enabled = enabled;
				return;
			}
		}
		
		//console.warn('Set validator for ' + fieldName + ' - enabled = ' + enabled + ' - could not find element');	
	}
}